@@ -37,6 +37,7 @@ from __future__ import division, absolute_import, print_function
 
 import mutagen
 import mutagen.id3
+import mutagen.mp3
 import mutagen.mp4
 import mutagen.flac
 import mutagen.asf
@@ -58,7 +59,7 @@ import struct
 import traceback
 
 
-__version__ = '0.8.0'
+__version__ = '0.10.1'
 __all__ = ['UnreadableFileError', 'FileTypeError', 'MediaFile']
 
 log = logging.getLogger(__name__)
@@ -949,7 +950,7 @@ class MP3ListDescStorageStyle(MP3DescStorageStyle, ListStorageStyle):
         for frame in mutagen_file.tags.getall(self.key):
             if frame.desc.lower() == self.description.lower():
                 if mutagen_file.tags.version == (2, 3, 0) and self.split_v23:
-                    return sum([el.split('/') for el in frame.text], start=[])
+                    return sum((el.split('/') for el in frame.text), [])
                 else:
                     return frame.text
         return []
@@ -1311,11 +1312,12 @@ class ListMediaField(MediaField):
     Uses ``get_list`` and set_list`` methods of its ``StorageStyle``
     strategies to do the actual work.
     """
-    def __get__(self, mediafile, _):
-        values = []
+    def __get__(self, mediafile, _=None):
         for style in self.styles(mediafile.mgfile):
-            values.extend(style.get_list(mediafile.mgfile))
-        return [_safe_cast(self.out_type, value) for value in values]
+            values = style.get_list(mediafile.mgfile)
+            if values:
+                return [_safe_cast(self.out_type, value) for value in values]
+        return []
 
     def __set__(self, mediafile, values):
         for style in self.styles(mediafile.mgfile):
@@ -1721,7 +1723,8 @@ class MediaFile(object):
         for property in cls.fields():
             yield property
         for property in ('length', 'samplerate', 'bitdepth', 'bitrate',
-                         'channels', 'format'):
+                         'bitrate_mode', 'channels', 'encoder_info',
+                         'encoder_settings', 'format'):
             yield property
 
     @classmethod
@@ -1907,22 +1910,33 @@ class MediaFile(object):
         MP3StorageStyle('TPE2'),
         MP4StorageStyle('aART'),
         StorageStyle('ALBUM ARTIST'),
+        StorageStyle('ALBUM_ARTIST'),
         StorageStyle('ALBUMARTIST'),
         ASFStorageStyle('WM/AlbumArtist'),
     )
     albumartists = ListMediaField(
         MP3ListDescStorageStyle(desc=u'ALBUMARTISTS'),
+        MP3ListDescStorageStyle(desc=u'ALBUM_ARTISTS'),
+        MP3ListDescStorageStyle(desc=u'ALBUM ARTISTS', read_only=True),
         MP4ListStorageStyle('----:com.apple.iTunes:ALBUMARTISTS'),
+        MP4ListStorageStyle('----:com.apple.iTunes:ALBUM_ARTISTS'),
+        MP4ListStorageStyle(
+            '----:com.apple.iTunes:ALBUM ARTISTS', read_only=True
+        ),
         ListStorageStyle('ALBUMARTISTS'),
+        ListStorageStyle('ALBUM_ARTISTS'),
+        ListStorageStyle('ALBUM ARTISTS', read_only=True),
         ASFStorageStyle('WM/AlbumArtists'),
     )
-    albumtype = MediaField(
-        MP3DescStorageStyle(u'MusicBrainz Album Type'),
-        MP4StorageStyle('----:com.apple.iTunes:MusicBrainz Album Type'),
-        StorageStyle('RELEASETYPE'),
-        StorageStyle('MUSICBRAINZ_ALBUMTYPE'),
+    albumtypes = ListMediaField(
+        MP3ListDescStorageStyle('MusicBrainz Album Type', split_v23=True),
+        MP4ListStorageStyle('----:com.apple.iTunes:MusicBrainz Album Type'),
+        ListStorageStyle('RELEASETYPE'),
+        ListStorageStyle('MUSICBRAINZ_ALBUMTYPE'),
         ASFStorageStyle('MusicBrainz/Album Type'),
     )
+    albumtype = albumtypes.single_field()
+
     label = MediaField(
         MP3StorageStyle('TPUB'),
         MP4StorageStyle('----:com.apple.iTunes:LABEL'),
@@ -1950,12 +1964,26 @@ class MediaFile(object):
         StorageStyle('ASIN'),
         ASFStorageStyle('MusicBrainz/ASIN'),
     )
-    catalognum = MediaField(
-        MP3DescStorageStyle(u'CATALOGNUMBER'),
-        MP4StorageStyle('----:com.apple.iTunes:CATALOGNUMBER'),
-        StorageStyle('CATALOGNUMBER'),
+    catalognums = ListMediaField(
+        MP3ListDescStorageStyle('CATALOGNUMBER', split_v23=True),
+        MP3ListDescStorageStyle('CATALOGID', read_only=True),
+        MP3ListDescStorageStyle('DISCOGS_CATALOG', read_only=True),
+        MP4ListStorageStyle('----:com.apple.iTunes:CATALOGNUMBER'),
+        MP4ListStorageStyle(
+            '----:com.apple.iTunes:CATALOGID', read_only=True
+        ),
+        MP4ListStorageStyle(
+            '----:com.apple.iTunes:DISCOGS_CATALOG', read_only=True
+        ),
+        ListStorageStyle('CATALOGNUMBER'),
+        ListStorageStyle('CATALOGID', read_only=True),
+        ListStorageStyle('DISCOGS_CATALOG', read_only=True),
         ASFStorageStyle('WM/CatalogNo'),
+        ASFStorageStyle('CATALOGID', read_only=True),
+        ASFStorageStyle('DISCOGS_CATALOG', read_only=True),
     )
+    catalognum = catalognums.single_field()
+
     barcode = MediaField(
         MP3DescStorageStyle(u'BARCODE'),
         MP4StorageStyle('----:com.apple.iTunes:BARCODE'),
@@ -1991,12 +2019,14 @@ class MediaFile(object):
         StorageStyle('SCRIPT'),
         ASFStorageStyle('WM/Script'),
     )
-    language = MediaField(
-        MP3StorageStyle('TLAN'),
-        MP4StorageStyle('----:com.apple.iTunes:LANGUAGE'),
-        StorageStyle('LANGUAGE'),
+    languages = ListMediaField(
+        MP3ListStorageStyle('TLAN'),
+        MP4ListStorageStyle('----:com.apple.iTunes:LANGUAGE'),
+        ListStorageStyle('LANGUAGE'),
         ASFStorageStyle('WM/Language'),
     )
+    language = languages.single_field()
+
     country = MediaField(
         MP3DescStorageStyle(u'MusicBrainz Album Release Country'),
         MP4StorageStyle('----:com.apple.iTunes:MusicBrainz '
@@ -2326,6 +2356,42 @@ class MediaFile(object):
                 return 0
             return int(self.filesize * 8 / self.length)
 
+    @property
+    def bitrate_mode(self):
+        """The mode of the bitrate used in the audio coding
+        (a string, eg. "CBR", "VBR" or "ABR").
+        Only available for the MP3 file format (empty where unavailable).
+        """
+        if hasattr(self.mgfile.info, 'bitrate_mode'):
+            return {
+                mutagen.mp3.BitrateMode.CBR: 'CBR',
+                mutagen.mp3.BitrateMode.VBR: 'VBR',
+                mutagen.mp3.BitrateMode.ABR: 'ABR',
+            }.get(self.mgfile.info.bitrate_mode, '')
+        else:
+            return ''
+
+    @property
+    def encoder_info(self):
+        """The name and/or version of the encoder used
+        (a string, eg. "LAME 3.97.0").
+        Only available for some formats (empty where unavailable).
+        """
+        if hasattr(self.mgfile.info, 'encoder_info'):
+            return self.mgfile.info.encoder_info
+        else:
+            return ''
+
+    @property
+    def encoder_settings(self):
+        """A guess of the settings used for the encoder (a string, eg. "-V2").
+        Only available for the MP3 file format (empty where unavailable).
+        """
+        if hasattr(self.mgfile.info, 'encoder_settings'):
+            return self.mgfile.info.encoder_settings
+        else:
+            return ''
+
     @property
     def format(self):
         """A string describing the file format/codec."""
